@@ -29,12 +29,12 @@ class Constants:
 	# PLATFORM INDEPENDENT CONSTANTS
 	EMAIL = "billy_bob_ming@yahoo.com"							  # site's email account
 	CGI_NAME = "ming.cgi"										  # CGI file's name (in case server is picky)
-	SERVER = "http://localhost/cgi-bin/%s" % CGI_NAME			  # CGI url (used in PrePal.py)
-	#SERVER = "http://billy-bob-ming.com/cgi-bin/%s" % CGI_NAME	  # CGI url (used in PrePal.py)
+	#SERVER = "http://localhost/cgibin/%s" % CGI_NAME			  # CGI url (used in PrePal.py)
+	SERVER = "http://billy-bob-ming.com/cgibin/%s" % CGI_NAME	  # CGI url (used in PrePal.py)
 	FILE_MAX = 512*1024											  # max size of file in FILES_DIR
 	INCOMING_MAX = 64*1024										  # max size allowed in incoming data
 	PLATES = 1													  # 0 if only one site.html, else 1 (0 is faster)
-	LOGGING = 1													  # on is 1, off is 0
+	LOGGING = 0													  # on is 1, off is 0
 	DEMO = 1													  # 1 makes log public
 	LOG_PASSWD = "your_passwd_here"								  # Log passwd, used to reset log
 	PRIVATE = "private"											  # dir trees hidden from log
@@ -51,8 +51,12 @@ class Constants:
 		FILES_DIR = "..\\data\\files"		 # incoming data handler's dir - must be read-write
 		LOG_DIR = FILES_DIR					 # where your log will be written - "." for cgi-bin
 	else:
-		DATA = "../data"					 # root of all your data files - can be read-only
-		FILES_DIR = "../data/files"			 # incoming data handler's dir - must be read-write-execute
+		if os.path.exists(os.path.expanduser("~/.my_machine")):
+			DATA = "../data"					 # root of all your data files - can be read-only
+			FILES_DIR = "../data/files"			 # incoming data handler's dir - must be read-write-execute
+		else:	
+			DATA =  os.path.expanduser("~/data") # root of all your data files - can be read-only
+			FILES_DIR = os.path.expanduser("~/data/files") # incoming data handler's dir - must be read-write-execute
 		LOG_DIR = FILES_DIR					 # where your log will be written - "." for cgi-bin
 
 	# DERIVED CONSTANTS
