@@ -97,7 +97,7 @@ class Logger:
 						total = dict[key][0]
 						diff  = dict[key][0] -  dict[key][1]
 						print '''<tr align=right><td>%d <td>%d <td align=center>
-						<a href="/cgi-bin/ming.cgi?page=%s">%s</a>''' % (diff, total, path, key[:-1])
+						<a href="/cgibin/ming.cgi?page=%s">%s</a>''' % (diff, total, path, key[:-1])
 		return now		
 
 	def __write_hdr(self):
